Header

Struct Header 

pub struct Header {
    pub magic: [u8; 4],
    pub version: (u8, u8),
    pub model_type: ModelType,
    pub metadata_size: u32,
    pub payload_size: u32,
    pub uncompressed_size: u32,
    pub compression: Compression,
    pub flags: Flags,
    pub quality_score: u8,
}
File header (32 bytes).

Fields

magic: [u8; 4]

Magic number (must be “APRN”)

version: (u8, u8)

Format version (major, minor)

model_type: ModelType

Model type identifier

metadata_size: u32

Metadata section size in bytes

payload_size: u32

Compressed payload size in bytes

uncompressed_size: u32

Uncompressed payload size (for allocation check)

compression: Compression

Compression algorithm

flags: Flags

Feature flags

quality_score: u8

Quality score (0-100, Poka-yoke validation) - APR-POKA-001 0 = no validation (F), 1-59 = failing, 60-100 = passing grades

Implementations

Source

impl Header

pub fn new(model_type: ModelType) -> Self

Create a new header.

pub fn to_bytes(&self) -> [u8; 32]

Serialize header to bytes (32 bytes).

pub fn from_bytes(bytes: &[u8]) -> Result<Self>

Parse header from bytes.

Errors

Returns an error on short input, bad magic, unsupported version, unknown model type, unknown compression, or a compression-bomb-sized payload.